@@ -53,7 +53,7 @@
 #define ENABLE_DEBUG
 
 #ifdef ENABLE_DEBUG
-#define DEBUG(x) (x)
+#define DEBUG(x) x
 #else
 #define DEBUG(x)
 #endif
@@ -188,9 +188,11 @@ static GbfProject *parent_class;
    Private prototypes
    ---------------------------------------------------------------------- */
 
+#ifdef NATIVE_GNU_REGEX
 static gboolean        queue_check                  (GbfMkfileProject      *project);
 static void            queue_push_op                (GbfMkfileProject      *project,
 						     GbfMkfileProjectOp    *op);
+#endif /* NATIVE_GNU_REGEX */
 static void            queue_destroy                (GbfMkfileProject      *project);
 
 static gboolean        uri_is_equal                 (const gchar       *uri1,
@@ -287,6 +289,8 @@ static void            gbf_mkfile_project_get_property  (GObject           *obje
  * - Operations are added to the head and retrieved from the tail
  */
 
+#ifdef NATIVE_GNU_REGEX
+
 static gboolean
 queue_check (GbfMkfileProject *project)
 {
@@ -347,6 +351,8 @@ queue_push_op (GbfMkfileProject *project, GbfMkfileProjectOp *op)
 		project->queue_handler_tag = g_idle_add ((GSourceFunc) queue_check, project);
 }
 
+#endif /* NATIVE_GNU_REGEX */
+
 static void
 queue_destroy (GbfMkfileProject *project)
 {
@@ -2676,6 +2682,7 @@ impl_build (GbfProject  *_project,
 	    const gchar *id,
 	    GError     **error)
 {
+#ifdef NATIVE_GNU_REGEX
 	GbfMkfileProject *project;
 	GbfMkfileProjectOp *op;
 
@@ -2688,12 +2695,17 @@ impl_build (GbfProject  *_project,
 
 	op->build_id = g_strdup (id);
 	queue_push_op (project, op);
+#else  /* NATIVE_GNU_REGEX */
+	UNIMPLEMENTED;
+        g_warning ("This method has been disabled until glib-2.14 is released");
+#endif /* NATIVE_GNU_REGEX */
 }
 
 static void
 impl_clean (GbfProject *_project,
 	    GError    **error)
 {
+#ifdef NATIVE_GNU_REGEX
 	GbfMkfileProject *project;
 	GbfMkfileProjectOp *op;
 
@@ -2706,6 +2718,10 @@ impl_clean (GbfProject *_project,
 	op->build_id = g_strdup (GBF_MKFILE_BUILD_ID_CLEAN);
 
 	queue_push_op (project, op);
+#else  /* NATIVE_GNU_REGEX */
+	UNIMPLEMENTED;
+        g_warning ("This method has been disabled until glib-2.14 is released");
+#endif /* NATIVE_GNU_REGEX */
 }
 
 static gboolean
@@ -3335,17 +3351,17 @@ impl_mimetype_for_type (GbfProject  *_project,
 			const gchar *type)
 {
 	if (!strcmp (type, "static_lib")) {
-		return "application/x-unix-archive";
+		return "application/x-archive";
 	} else if (!strcmp (type, "shared_lib")) {
-		return "application/x-shared-library";
+		return "application/x-sharedlib";
 	} else if (!strcmp (type, "man")) {
 		return "text/x-troff-man";
 	} else if (!strcmp (type, "data")) {
 		return "application/octet-stream";
 	} else if (!strcmp (type, "program")) {
-		return "application/x-executable-binary";
+		return "application/x-executable";
 	} else if (!strcmp (type, "script")) {
-		return "text/x-sh";
+		return "text/x-shellscript";
 	} else if (!strcmp (type, "info")) {
 		return "application/x-tex-info";
 	} else {
