@@ -625,21 +625,25 @@ gbf_project_util_add_source (GbfProjectModel *model,
                              const gchar     *default_group,
                              const gchar     *default_uri)
 {
-	gchar* uri = g_strdup(default_uri);
-	GList* uris = g_list_append(NULL, uri);
-	GList* new_sources = 
-		gbf_project_util_add_source_multi(model, parent, default_target, default_group, uris);
-	g_free(uri);
+        GList* new_sources;
+	gchar* uri = NULL;
+	GList* uris = NULL;
+        
+        if (default_uri) {
+            uri = g_strdup (default_uri);
+            uris = g_list_append (NULL, uri);
+        }
+	new_sources = 
+		gbf_project_util_add_source_multi (model, parent,
+                                                   default_target,
+                                                   default_group, uris);
+	g_free (uri);
 	
-	if (g_list_length(new_sources))
+	if (new_sources && g_list_length (new_sources))
 	{
-		gchar* new_source = g_strdup(new_sources->data);
-		while(new_sources) 
-		{
-			g_free(new_sources->data);
-			new_sources = g_list_next(new_sources);
-		}
-		g_list_free(new_sources);
+		gchar* new_source = g_strdup (new_sources->data);
+                g_list_foreach (new_sources, (GFunc) g_free, NULL);
+		g_list_free (new_sources);
 		return new_source;
 	}
 	else
